@@ -4,6 +4,5 @@ files (like output from "analyze" and the xyz-format file).
 """
 
 __all__ = ['system', 'parameterfile', 'tinkerfiles', 'XyzFile']
-__authors__ = 'Jason Swails'
 
-from parmed.tinker.tinkerfiles import XyzFile
+from .tinkerfiles import XyzFile
