@@ -1,13 +1,9 @@
 """
 Tests the functionality in the parmed.unit package.
 """
-from __future__ import division
-
 import utils
 import numpy as np
 from parmed import unit as u
-from parmed.utils.six import string_types
-from parmed.utils.six.moves import zip
 import copy
 import math
 import unittest
@@ -284,10 +280,7 @@ class TestUnits(utils.QuantityTestCase):
         self.assertEqual(s, u.Quantity([1, 2, 3, 4], u.angstroms))
         t[0] = 2
         self.assertEqual(t, [2, 2, 3, 4])
-        if not utils.openmm_version or utils.openmm_version > (6, 2):
-            self.assertEqual(s, u.Quantity([1, 2, 3, 4], u.angstroms))
-        else:
-            t[0] = 1
+        self.assertEqual(s, u.Quantity([1, 2, 3, 4], u.angstroms))
         t = s.value_in_unit(u.angstroms)
         self.assertEqual(t, [1, 2, 3, 4])
         self.assertEqual(s, u.Quantity([1, 2, 3, 4], u.angstroms))
@@ -571,12 +564,11 @@ class TestUnits(utils.QuantityTestCase):
     def testQuantityCollectionMethods(self):
         """ Tests some sequence methods on Quantity objects (no numpy) """
         seq = [1, 2, 3, 4] * u.meters
-        if not utils.openmm_version or utils.openmm_version > (6, 2):
-            self.assertEqual(seq.sum(), 10*u.meters)
-            self.assertEqual(seq.mean(), 2.5*u.meters)
-            self.assertEqual(seq.max(), 4*u.meters)
-            self.assertEqual(seq.min(), 1*u.meters)
-            self.assertAlmostEqualQuantities(seq.std(), 1.1180339887498949*u.meters)
+        self.assertEqual(seq.sum(), 10*u.meters)
+        self.assertEqual(seq.mean(), 2.5*u.meters)
+        self.assertEqual(seq.max(), 4*u.meters)
+        self.assertEqual(seq.min(), 1*u.meters)
+        self.assertAlmostEqualQuantities(seq.std(), 1.1180339887498949*u.meters)
 
     def testString(self):
         """ Tests unit handling with strings, which should be dimensionless """
@@ -630,11 +622,11 @@ class TestNumpyUnits(utils.QuantityTestCase):
         """ Tests the internal _is_string method with numpy Quantities """
         a = np.array([[1, 2, 3], [4, 5, 6]])
         self.assertIsInstance("", str)
-        self.assertTrue(isinstance("", string_types))
-        self.assertTrue(isinstance("t", string_types))
-        self.assertTrue(isinstance("test", string_types))
-        self.assertFalse(isinstance(3, string_types))
-        self.assertFalse(isinstance(a, string_types))
+        self.assertTrue(isinstance("", str))
+        self.assertTrue(isinstance("t", str))
+        self.assertTrue(isinstance("test", str))
+        self.assertFalse(isinstance(3, str))
+        self.assertFalse(isinstance(a, str))
 
     def testNumpyFunctions(self):
         """ Tests various numpy attributes that they result in Quantities """
